"""tooltip_title"""
from dash import html
import dash_bootstrap_components as dbc


def tooltip_title(title, tooltiptext):
    """Creates a tooltip title for explaining metrics"""

    land_constrained_tooltip = html.Div(
        [
            html.H1(
                [
                    title,
                    html.Span(
                        " ⓘ",
                        id="tooltip-target",
                        style={"cursor": "pointer"},
                    ),
                ],
                className="govuk-heading-m govuk-!-margin-bottom-1",
            ),
            dbc.Tooltip(
                tooltiptext,
                target="tooltip-target",
                class_name="tooltip tooltiptext",
                style={"color": "white", "font-size": 12, "width": "10px"},
            ),
        ]
    )

    return land_constrained_tooltip



"""Message for when selection does not provide data."""


def no_data_message(metric: str, financial_year: str) -> list[str]:
    """Message for when selection does not provide data."""
    return [
        f"The selection you have made has no data for {metric.lower()}. ",
        f"This is probably because data has not been published for {financial_year}, ",
        "please select a different year.",
    ]



"""DashPatterns enum"""
from enum import Enum


class DashPatterns(str, Enum):
    """
    Sets out valid dash patterns used by plotly/plotly express.
    """

    SOLID = "solid"
    DOT = "dot"
    DASH = "dash"
    LONG_DASH = "longdash"
    DASH_DOT = "dashdot"
    LONG_DASH_DOT = "longdashdot"



"""Module containing standard Plotly figures for use in dashboards.

Contains:
- ChartData: A dataclass for containing standard information useful for
    plotting charts.
- line_chart: Create and return a plotly express line chart with
    standard formatting.
- enums: Module containing enums used in the construction of plotly figures.
    - DashPatterns: Sets out valid dash patterns used by plotly/plotly express.
- styles: Module containing classes & functions used for styling plotly figures.
    - LineStyle: Dataclass containing information on how to style a line on a line
        chart.
"""
from . import enums
from . import styles

# from .chart_data import ChartData
# from .line_chart import line_chart



"""ChartData dataclass"""
# from dataclasses import dataclass
# from typing import Optional

# import pandas as pd


# @dataclass
# class ChartData:
#     """
#     Dataclass containing standard information useful for plotting charts.

#     Attributes:
#         dataframe (pd.DataFrame): The dataframe containing the data for the chart.
#         x_column (str): The label of the column containing the x axis values.
#         y_column (str): The label of the column containing the y axis values.
#         category_column (str, optional): If there are multiple categories in the data,
#             this column gives the value to categorize them. Defaults to None.
#     """

#     dataframe: pd.DataFrame
#     x_column: str
#     y_column: str
#     category_column: Optional[str] = None



"""get_chart_for_download"""
from gov_uk_dashboards.constants import MAIN_TITLE, SUBTITLE


def get_chart_for_download(self, fig):
    """Returns a fig with title and subtitle for download as png"""
    main_title = self.title_data[MAIN_TITLE]
    subtitle = self.title_data[SUBTITLE]
    footnote = getattr(self, "footnote", None)

    fig.update_layout(
        title={
            "text": f"<b><span style='color: black; margin: 0px 0px 5px'>{main_title}</span></b>",
            "x": 0.01,
            "xanchor": "left",
        },
        title_subtitle={
            "text": f"<b><span style='color: black; margin: 0px 0px 5px'>{subtitle}</span></b>"
        },
        annotations=[
            {
                "text": f"<span style='color: black; font-size: 18px;'>{footnote}</span>",
                "x": -0.01,
                "y": -0.4,  # Bottom of the plotting area
                "xref": "paper",
                "yref": "paper",
                "xanchor": "left",
                "yanchor": "top",
                "showarrow": False,
                "align": "left",
            }
        ]
        if footnote is not None
        else [],
    )
    return fig
